import click
import pathlib
import subprocess


@click.command()
@click.option(
    "--output",
    "-o",
    help="Documentation output path",
    default="./docs",
    type=click.Path(file_okay=False, path_type=pathlib.Path),
)
@click.pass_context
def docs(ctx: click.Context, output: pathlib.Path):
    """Generate and export API documentation using pdoc"""
    import pkg_resources

    try:
        pkg_resources.get_distribution("pdoc>=8.0.1")
    except pkg_resources.DistributionNotFound:
        click.echo(
            f"Error: pdoc was not found, maybe you need to install it. Try:\n" "\n" '$ pip install "pdoc>=8.0.1"\n'
        )
        ctx.exit(1)
    output.mkdir(parents=True, exist_ok=True)
    command = [
        "python",
        "-m",
        "pdoc",
        "--docformat",
        "google",
        "--output-directory",
        str(output),
        "flaschengeist",
    ]
    click.echo(f"Running command: {command}")
    subprocess.check_call(command)
